dhclient

package
v0.0.0-...-baa19d7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2015 License: MIT Imports: 6 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddNameServers

func AddNameServers(addrs []net.IP, configpath, configpathbackup string) (err error)

AddNameServers reads the list of ip addresses, dhclient daemon configuration file path. On first step backup configuration file if this do not exist. On second step add dns addresses to dhclient config.

func RemoveNameServers

func RemoveNameServers(configpath, configpathbackup string) (err error)

RemoveNameServers consume dhclient daemon configuration file path and revert previously called AddNameServers method effect.

Types

This section is empty.

Jump to