Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddNameServers ¶
AddNameServers reads the list of ip addresses, dhclient daemon configuration file path. On first step backup configuration file if this do not exist. On second step add dns addresses to dhclient config.
func RemoveNameServers ¶
RemoveNameServers consume dhclient daemon configuration file path and revert previously called AddNameServers method effect.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.